from pybel import Molecule
from openbabel import OBElementTable

element_table = OBElementTable()
header = '# Generated using pybel-orca'


def write_orca_input(mol, **optional):
    if not isinstance(mol, Molecule):
        mol = Molecule(mol)

    # Comments
    orca_inp = get_comments(optional)

    # Keywords part
    orca_inp += get_keywords(optional)

    # xyz part
    orca_inp += get_xyz(mol)

    return orca_inp


def get_keywords(optional):
    result = '!'
    if 'keywords' in optional:
        result += ' '

        if isinstance(optional['keywords'], list):
            result += ' '.join(optional['keywords'])
        else:
            result += optional['keywords']

    return result + '\n'


def get_xyz(mol):
    xyz = ' '.join(
        map(str, [
            '*xyz',
            mol.OBMol.GetTotalCharge(),
            mol.OBMol.GetTotalSpinMultiplicity()
        ])
    ) + '\n'

    for atom in mol:
        atom_geometry_data = map(str, [
            element_table.GetSymbol(atom.atomicnum),
            atom.vector.GetX(),
            atom.vector.GetY(),
            atom.vector.GetZ()
        ])

        xyz += ' '.join(atom_geometry_data) + '\n'

    xyz += '*'

    return xyz


def get_comments(optional):
    comment = header + '\n'

    if 'comment' in optional:
        comment += '# ' + optional['comment']

    return comment + '\n'



#!/usr/bin/env python

from openbabel import OBConversion, OBMol
from pybel_orca import write_orca_input

import click

# Create an instance of OBMol and OBConversion
mol = OBMol()
converter = OBConversion()


@click.command()
@click.option('--input_type', default='pdb', help='Input file type', type=click.STRING)
@click.option('--keywords', help='ORCA input Keywords', type=click.STRING)
@click.argument('input_file', type=click.Path(readable=True, exists=True))
@click.argument('output_file', type=click.Path(writable=True, resolve_path=True))
def convert(input_type, keywords, input_file, output_file):
    """Welcome to pybel orca converter!"""

    # Read a pdb file
    converter.SetInFormat(str(input_type))
    converter.ReadFile(mol, str(input_file))

    # Write orca input file
    result = write_orca_input(
        mol,
        # comment=comment,
        keywords=keywords
    )

    file = open(output_file, 'w')
    file.write(result)
    file.close()

    click.echo('ORCA input file successfully generated at:\n=> %s' % output_file)


if __name__ == '__main__':
    convert()



from setuptools import setup

setup(
    name='pybel-orca',
    packages=['pybel_orca'],
    version='0.2',
    py_modules=['bin/pybel-orca'],
    install_requires=[
        'Click',
        'openbabel',
    ],
    description = 'ORCA input file writer',
    author = 'Mohamad Mohebifar',
    author_email = 'mmohebifar@mun.ca',
    url = 'https://github.com/mohebifar/pybel-orca',
    download_url = 'https://github.com/mohebifar/pybel-orca/tarball/0.1',
    keywords = ['pybel-orca', 'rowley'],
    classifiers = [],
)
